| Title: | Easily Install and Load the 'pqverse' |
|---|---|
| Description: | The 'pqverse' is a set of packages for metabarcoding analysis that share the phyloseq object as their central data structure. This package makes it easy to install and load multiple 'pqverse' packages in a single step. |
| Authors: | Adrien Taudière [aut, cre] (ORCID: <https://orcid.org/0000-0003-1088-1182>) |
| Maintainer: | Adrien Taudière <[email protected]> |
| License: | AGPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-06-22 19:30:25 UTC |
| Source: | https://github.com/adrientaudiere/pqverse |
List all pqverse packages
pqverse_packages(include_self = TRUE)pqverse_packages(include_self = TRUE)
include_self |
Include pqverse in the list? |
A character vector of package names.
Check which pqverse packages are out of date and optionally update them.
pqverse_update()pqverse_update()